@@ -4,14 +4,14 @@ import unittest
 import numpy as np
 from sklearn.model_selection import RepeatedKFold
 from sklearn.model_selection import train_test_split
-from sklearn.preprocessing import label_binarize, MinMaxScaler, StandardScaler, OneHotEncoder
+from sklearn.preprocessing import label_binarize
 from skopt import BayesSearchCV
 
 from helpsk import validation
 from helpsk.pandas import print_dataframe
 from helpsk.sklearn_eval import MLExperimentResults
-from helpsk.sklearn_pipeline import CustomOrdinalEncoder
-from helpsk.sklearn_search import ClassifierSearchSpace, ClassifierSearchSpaceModels
+from helpsk.sklearn_search_bayesian import *
+from helpsk.sklearn_search_bayesian_classification import *
 from helpsk.utility import redirect_stdout_to_file
 from tests.helpers import get_data_credit, get_test_path, clean_formatted_dataframe
 
@@ -20,6 +20,7 @@ from tests.helpers import get_data_credit, get_test_path, clean_formatted_datafr
 class TestSklearnSearch(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
+        pass
         credit_data = get_data_credit()
         credit_data.loc[0:46, ['duration']] = np.nan
         credit_data.loc[25:75, ['checking_status']] = np.nan
@@ -29,225 +30,285 @@ class TestSklearnSearch(unittest.TestCase):
         y_full = label_binarize(y_full, classes=['good', 'bad']).flatten()
         X_train, X_test, y_train, y_test = train_test_split(X_full, y_full, test_size=0.2, random_state=42)  # noqa
         del y_full, X_full
-        cls.default_search_space = ClassifierSearchSpace(data=X_train)
         cls.X_train = X_train
         cls.y_train = y_train
-        cls.search_space_used = ClassifierSearchSpace(
-            data=X_train,
-            models=[
-                ClassifierSearchSpaceModels.XGBoost,
-                ClassifierSearchSpaceModels.LogisticRegression
-            ],
-            iterations=[5, 5]
+
+    @staticmethod
+    def to_string(obj):
+        return str(obj). \
+            replace(", '", ",\n'"). \
+            replace('{', '{\n'). \
+            replace('}', '\n}'). \
+            replace(', ({', ',\n({')
+
+    def test_pipeline(self):
+        # this will be the same for all inherited classes, so just test base.
+        with open(get_test_path() + '/test_files/sklearn_search/search_space_base__pipeline.txt', 'w') as file:
+            file.write(str(SearchSpaceBase.pipeline(data=self.X_train)))
+
+    def test_ModelBayesianSearchSpace_params(self):
+        search_space = LogisticBayesianSearchSpace(
+            C=None,
         )
-        # pip install scikit-optimize
+        model_space = search_space.search_spaces()[0][0]
+        model_params = [x for x in model_space.keys() if x.startswith('model__')]
+        self.assertEqual(len(model_params), 0)
 
-        cls.bayes_search = BayesSearchCV(
-            estimator=cls.search_space_used.pipeline(),  # noqa
-            search_spaces=cls.search_space_used.search_spaces(),  # noqa
-            cv=RepeatedKFold(n_splits=3, n_repeats=1, random_state=42),  # 3 fold 1 repeat CV
-            scoring='roc_auc',
-            refit=False,  # required if passing in multiple scorers
-            return_train_score=False,
-            n_jobs=-1,
-            verbose=0,
-            random_state=42,
+        model_mappings = [x for x in search_space.param_name_mappings().keys() if x.startswith('model__')]
+        self.assertEqual(len(model_mappings), 0)
+        del search_space, model_space, model_mappings
+
+        search_space = LinearSVCBayesianSearchSpace(
+            C=None,
         )
-        cls.bayes_search.fit(X_train, y_train)  # noqa
+        model_space = search_space.search_spaces()[0][0]
+        model_params = [x for x in model_space.keys() if x.startswith('model__')]
+        self.assertEqual(len(model_params), 0)
 
-    def test_ClassifierSearchSpace(self):
+        model_mappings = [x for x in search_space.param_name_mappings().keys() if x.startswith('model__')]
+        self.assertEqual(len(model_mappings), 0)
+        del search_space, model_space, model_mappings
 
-        transformer_search_space = ClassifierSearchSpace._build_transformer_search_space()
-        self.assertEqual(list(transformer_search_space.keys()),
-                         ['prep__numeric__imputer__transformer',
-                          'prep__numeric__scaler__transformer',
-                          'prep__non_numeric__encoder__transformer'])
-
-        categorical = transformer_search_space['prep__numeric__imputer__transformer']
-        self.assertEqual(len(categorical.categories), 3)
-        self.assertEqual(categorical.categories[0].strategy, 'mean')
-        self.assertEqual(categorical.categories[1].strategy, 'median')
-        self.assertEqual(categorical.categories[2].strategy, 'most_frequent')
-        del categorical
-
-        categorical = transformer_search_space['prep__numeric__scaler__transformer']
-        self.assertEqual(len(categorical.categories), 3)
-        self.assertIsNone(categorical.categories[0])
-        self.assertIsInstance(categorical.categories[1], MinMaxScaler)
-        self.assertIsInstance(categorical.categories[2], StandardScaler)
-        del categorical
-
-        categorical = transformer_search_space['prep__non_numeric__encoder__transformer']
-        self.assertEqual(len(categorical.categories), 2)
-        self.assertIsInstance(categorical.categories[0], OneHotEncoder)
-        self.assertIsInstance(categorical.categories[1], CustomOrdinalEncoder)
-        del categorical
-        del transformer_search_space
-
-        self.assertRaises(AssertionError,
-                          lambda: ClassifierSearchSpace._build_transformer_search_space(
-                              scaler_min_max=False,
-                              scaler_standard=False,
-                              scaler_none=False,
-                          ))
-        transformer_search_space = ClassifierSearchSpace._build_transformer_search_space(
-            scaler_min_max=True,
-            scaler_standard=False,
-            scaler_none=False,
+        search_space = ExtraTreesBayesianSearchSpace(
+            max_features=None,
+            max_depth=None,
+            n_estimators=None,
+            min_samples_split=None,
+            min_samples_leaf=None,
+            max_samples=None,
+            criterion=None,
         )
-        values = transformer_search_space['prep__numeric__scaler__transformer'].categories
-        self.assertEqual(len(values), 1)
-        self.assertIsInstance(values[0], MinMaxScaler)
-        del values
-        del transformer_search_space
+        model_space = search_space.search_spaces()[0][0]
+        model_params = [x for x in model_space.keys() if x.startswith('model__')]
+        self.assertEqual(len(model_params), 0)
 
-        transformer_search_space = ClassifierSearchSpace._build_transformer_search_space(
-            scaler_min_max=False,
-            scaler_standard=True,
-            scaler_none=False,
+        model_mappings = [x for x in search_space.param_name_mappings().keys() if x.startswith('model__')]
+        self.assertEqual(len(model_mappings), 0)
+
+        search_space = RandomForestBayesianSearchSpace(
+            max_features=None,
+            max_depth=None,
+            n_estimators=None,
+            min_samples_split=None,
+            min_samples_leaf=None,
+            max_samples=None,
+            criterion=None,
         )
-        values = transformer_search_space['prep__numeric__scaler__transformer'].categories
-        self.assertEqual(len(values), 1)
-        self.assertIsInstance(values[0], StandardScaler)
-        del values
-        del transformer_search_space
+        model_space = search_space.search_spaces()[0][0]
+        model_params = [x for x in model_space.keys() if x.startswith('model__')]
+        self.assertEqual(len(model_params), 0)
 
-        transformer_search_space = ClassifierSearchSpace._build_transformer_search_space(
-            imputer_strategies=['most_frequent'],
-            scaler_min_max=False,
-            scaler_standard=False,
-            encoder_one_hot=True,
-            encoder_ordinal=False
+        model_mappings = [x for x in search_space.param_name_mappings().keys() if x.startswith('model__')]
+        self.assertEqual(len(model_mappings), 0)
+
+        search_space = XGBoostBayesianSearchSpace(
+            max_depth=None,
+            learning_rate=None,
+            n_estimators=None,
+            min_child_weight=None,
+            subsample=None,
+            colsample_bytree=None,
+            colsample_bylevel=None,
+            reg_alpha=None,
+            reg_lambda=None,
         )
-        self.assertEqual(list(transformer_search_space.keys()),
-                         ['prep__numeric__imputer__transformer',
-                          'prep__numeric__scaler__transformer',
-                          'prep__non_numeric__encoder__transformer'])
+        model_space = search_space.search_spaces()[0][0]
+        model_params = [x for x in model_space.keys() if x.startswith('model__')]
+        self.assertEqual(len(model_params), 0)
 
-        categorical = transformer_search_space['prep__numeric__imputer__transformer']
-        self.assertEqual(len(categorical.categories), 1)
-        self.assertEqual(categorical.categories[0].strategy, 'most_frequent')
-        del categorical
+        model_mappings = [x for x in search_space.param_name_mappings().keys() if x.startswith('model__')]
+        self.assertEqual(len(model_mappings), 0)
 
-        categorical = transformer_search_space['prep__numeric__scaler__transformer']
-        self.assertEqual(len(categorical.categories), 1)
-        self.assertIsNone(categorical.categories[0])
-        del categorical
+    def test_ModelBayesianSearchSpace(self):
 
-        categorical = transformer_search_space['prep__non_numeric__encoder__transformer']
-        self.assertEqual(len(categorical.categories), 1)
-        self.assertIsInstance(categorical.categories[0], OneHotEncoder)
-        del categorical
-        del transformer_search_space
+        def test_search_space(search_object, modified_args):
+            default_space = search_object()
+            class_name = default_space.__class__.__name__
 
-        def to_string(obj):
-            return str(obj).\
-                replace(", '", ",\n'").\
-                replace('{', '{\n').\
-                replace('}', '\n}').\
-                replace(', ({', ',\n({')
+            with open(get_test_path() + f'/test_files/sklearn_search/{class_name}_search_spaces__default.txt', 'w') as file:
+                file.write(TestSklearnSearch.to_string(default_space.search_spaces()))
 
-        # default space for logistic regression
-        logistic_space = ClassifierSearchSpace._search_space_logistic()
-        self.assertEqual(list(logistic_space.keys()),
-                         ['model',
-                          'model__C',
-                          'prep__numeric__imputer__transformer',
-                          'prep__numeric__scaler__transformer',
-                          'prep__non_numeric__encoder__transformer'])
+            default_mappings = default_space.param_name_mappings()
+            self.assertEqual(default_space.search_spaces()[0][0].keys(), default_mappings.keys())
+            with open(get_test_path() + f'/test_files/sklearn_search/{class_name}_param_name_mappings.txt', 'w') as file:
+                file.write(TestSklearnSearch.to_string(default_mappings))
 
-        with open(get_test_path() + '/test_files/sklearn_search/logistic_space_default.txt', 'w') as file:
-            file.write(to_string(logistic_space))
-        del logistic_space
+            self.assertIsInstance(default_space.search_spaces(), list)
+            self.assertEqual(len(default_space.search_spaces()), 2)
+            self.assertIsInstance(default_space.search_spaces()[0], tuple)
+            self.assertIsInstance(default_space.search_spaces()[1], tuple)
+            self.assertIsInstance(default_space.search_spaces()[0][0], dict)
+            self.assertIsInstance(default_space.search_spaces()[0][1], int)
+            self.assertIsInstance(default_space.search_spaces()[1][0], dict)
+            self.assertIsInstance(default_space.search_spaces()[1][1], int)
 
-        # search space for logistic regression with modified params
-        logistic_space = ClassifierSearchSpace._search_space_logistic(
+            from skopt.space import Categorical
+            categorical = default_space.search_spaces()[0][0]['model']
+            self.assertIsInstance(categorical, Categorical)
+            del default_space, categorical
+
+            modified_space = search_object(
+                **modified_args,
+                iterations=30,
+                include_default_model=False,
+                imputers=Categorical([SimpleImputer(strategy='most_frequent')]),
+                scalers=Categorical([None]),
+                pca=Categorical([None]),
+                encoders=Categorical([CustomOrdinalEncoder()]),
+                random_state=42
+            )
+
+            with open(get_test_path() + f'/test_files/sklearn_search/{class_name}_search_spaces__modified.txt', 'w') as file:
+                file.write(TestSklearnSearch.to_string(modified_space.search_spaces()))
+
+            self.assertEqual(default_mappings, modified_space.param_name_mappings())
+
+            self.assertIsInstance(modified_space.search_spaces(), list)
+            self.assertEqual(len(modified_space.search_spaces()), 1)
+            self.assertIsInstance(modified_space.search_spaces()[0], tuple)
+            self.assertIsInstance(modified_space.search_spaces()[0][0], dict)
+            self.assertIsInstance(modified_space.search_spaces()[0][1], int)
+            self.assertEqual(modified_space.search_spaces()[0][1], 30)
+
+            categorical = modified_space.search_spaces()[0][0]['model']
+            self.assertIsInstance(categorical, Categorical)
+            del modified_space, categorical
+
+        # with self.subTest(i='LogisticBayesianSearchSpace'):
+        args = dict(
+            C=Real(1e-5, 1e+3, prior='uniform'),
             solver='sag',
             max_iter=999,
-            C=(1e-5, 1e+3),  # noqa
-            imputer_strategies=['most_frequent'],  # noqa
-            random_state=42
         )
-        self.assertEqual(list(logistic_space.keys()),
-                         ['model',
-                          'model__C',
-                          'prep__numeric__imputer__transformer',
-                          'prep__numeric__scaler__transformer',
-                          'prep__non_numeric__encoder__transformer'])
-        with open(get_test_path() + '/test_files/sklearn_search/logistic_space_modified.txt', 'w') as file:
-            file.write(to_string(logistic_space))
-        del logistic_space
+        test_search_space(LogisticBayesianSearchSpace, modified_args=args)
 
-        # default space for xgboost
-        xgboost_space = ClassifierSearchSpace._search_space_xgboost()
-        self.assertEqual(list(xgboost_space.keys()),
-                         ['model',
-                          'model__max_depth',
-                          'model__learning_rate',
-                          'model__n_estimators',
-                          'model__min_child_weight',
-                          'model__subsample',
-                          'model__colsample_bytree',
-                          'model__colsample_bylevel',
-                          'model__reg_alpha',
-                          'model__reg_lambda',
-                          'prep__numeric__imputer__transformer',
-                          'prep__numeric__scaler__transformer',
-                          'prep__non_numeric__encoder__transformer'])
-        with open(get_test_path() + '/test_files/sklearn_search/xgboost_space_default.txt', 'w') as file:
-            file.write(to_string(xgboost_space))
-        del xgboost_space
+        args = dict(
+            C=Real(1e-5, 1e+3),
+        )
+        test_search_space(LinearSVCBayesianSearchSpace, modified_args=args)
 
-        # search space for xgboost with modified params
-        xgboost_space = ClassifierSearchSpace._search_space_xgboost(
+        args = dict(
+            max_features=Real(0.06, 0.92),
+            max_depth=Integer(4, 101),
+            n_estimators=Integer(666, 6666),
+            min_samples_split=Integer(5, 55),
+            min_samples_leaf=Integer(2, 55),
+            max_samples=Real(0.8, 0.9),
+            criterion=Categorical(['entropy']),
+        )
+        test_search_space(ExtraTreesBayesianSearchSpace, modified_args=args)
+
+        args = dict(
+            max_features=Real(0.06, 0.92),
+            max_depth=Integer(5, 102),
+            n_estimators=Integer(6666, 66666),
+            min_samples_split=Integer(3, 52),
+            min_samples_leaf=Integer(5, 52),
+            max_samples=Real(0.7, 0.99),
+            criterion=Categorical(['gini']),
+        )
+        test_search_space(RandomForestBayesianSearchSpace, modified_args=args)
+
+        args = dict(
             eval_metric='logloss',
-            max_depth=(2, 30),
-            n_estimators=(10, 10000),
-            learning_rate=(0.01111, 0.3333),
-            colsample_bytree=(0.01234, 1123),
-            subsample=(0.1111, 0.999),
-            imputer_strategies=['median'],
-            random_state=42
+            max_depth=Integer(2, 30),
+            n_estimators=Integer(10, 10000),
+            learning_rate=Real(0.01111, 0.3333),
+            colsample_bytree=Real(0.01234, 1123),
+            subsample=Real(0.1111, 0.999),
         )
-        self.assertEqual(list(xgboost_space.keys()),
-                         ['model',
-                          'model__max_depth',
-                          'model__learning_rate',
-                          'model__n_estimators',
-                          'model__min_child_weight',
-                          'model__subsample',
-                          'model__colsample_bytree',
-                          'model__colsample_bylevel',
-                          'model__reg_alpha',
-                          'model__reg_lambda',
-                          'prep__numeric__imputer__transformer',
-                          'prep__numeric__scaler__transformer',
-                          'prep__non_numeric__encoder__transformer'])
-        with open(get_test_path() + '/test_files/sklearn_search/xgboost_space_modified.txt', 'w') as file:
-            file.write(to_string(xgboost_space))
-        del xgboost_space
+        test_search_space(XGBoostBayesianSearchSpace, modified_args=args)
 
-        pipeline = self.default_search_space.pipeline()
-        with open(get_test_path() + '/test_files/sklearn_search/pipeline_default.txt', 'w') as file:
-            file.write(to_string(pipeline))
-        del pipeline
+    def test_BayesianSearchSpace(self):
+        search_space = BayesianSearchSpace(self.X_train,
+                                           model_type='classification',
+                                           iterations=45, random_state=42)
+        self.assertEqual(str(SearchSpaceBase.pipeline(data=self.X_train)), str(search_space.pipeline()))
 
-        search_spaces = self.default_search_space.search_spaces()
-        with open(get_test_path() + '/test_files/sklearn_search/search_spaces_default.txt', 'w') as file:
-            file.write(to_string(search_spaces))
-        del search_spaces
+        with open(get_test_path() + '/test_files/sklearn_search/BayesianSearchSpace_search_spaces.txt', 'w') as file:
+            file.write(TestSklearnSearch.to_string(search_space.search_spaces()))
 
-        mappings = self.default_search_space.param_name_mappings()
-        with open(get_test_path() + '/test_files/sklearn_search/param_name_mappings_default.txt', 'w') as file:
-            file.write(to_string(mappings))
+        self.assertIsInstance(search_space.search_spaces(), list)
+
+        for space in search_space.search_spaces():
+            self.assertIsInstance(space, tuple)
+            self.assertIsInstance(space[0], dict)
+            self.assertIsInstance(space[1], int)
+
+        with open(get_test_path() + '/test_files/sklearn_search/BayesianSearchSpace_param_name_mappings.txt', 'w') as file:
+            file.write(TestSklearnSearch.to_string(search_space.param_name_mappings()))
+        del search_space
+
+        search_space = BayesianSearchSpace(self.X_train,
+                                           model_type='regression',
+                                           iterations=45, random_state=42)
+        self.assertEqual(str(SearchSpaceBase.pipeline(data=self.X_train)), str(search_space.pipeline()))
+
+        with open(get_test_path() + '/test_files/sklearn_search/BayesianSearchSpace_search_spaces__regression.txt', 'w') as file:
+            file.write(TestSklearnSearch.to_string(search_space.search_spaces()))
+
+        self.assertIsInstance(search_space.search_spaces(), list)
+
+        for space in search_space.search_spaces():
+            self.assertIsInstance(space, tuple)
+            self.assertIsInstance(space[0], dict)
+            self.assertIsInstance(space[1], int)
+
+        with open(get_test_path() + '/test_files/sklearn_search/BayesianSearchSpace_param_name_mappings__regression.txt', 'w') as file:
+            file.write(TestSklearnSearch.to_string(search_space.param_name_mappings()))
+        del search_space
+
+        search_space = BayesianSearchSpace(
+            self.X_train,
+            model_search_spaces= [
+                br.ElasticNetBayesianSearchSpace(encoders=None, pca=None, iterations=45, random_state=42),
+                br.ExtraTreesBayesianSearchSpace(encoders=None, pca=None, iterations=45, random_state=42),
+                br.RandomForestBayesianSearchSpace(encoders=None, pca=None, iterations=45, random_state=42),
+                br.XGBoostBayesianSearchSpace(encoders=None, pca=None, iterations=45, random_state=42),
+
+            ],
+        )
+        self.assertEqual(str(SearchSpaceBase.pipeline(data=self.X_train)), str(search_space.pipeline()))
+
+        with open(get_test_path() + '/test_files/sklearn_search/BayesianSearchSpace_search_spaces__regression_custom.txt', 'w') as file:
+            file.write(TestSklearnSearch.to_string(search_space.search_spaces()))
+
+        self.assertIsInstance(search_space.search_spaces(), list)
+
+        for space in search_space.search_spaces():
+            self.assertIsInstance(space, tuple)
+            self.assertIsInstance(space[0], dict)
+            self.assertIsInstance(space[1], int)
+
+        with open(get_test_path() + '/test_files/sklearn_search/BayesianSearchSpace_param_name_mappings__regression_custom.txt', 'w') as file:
+            file.write(TestSklearnSearch.to_string(search_space.param_name_mappings()))
 
     def test_MLExperimentResults_multi_model(self):
 
+        search_space = BayesianSearchSpace(self.X_train,
+                                           model_search_spaces=[
+                                               XGBoostBayesianSearchSpace(iterations=4),
+                                               LogisticBayesianSearchSpace(iterations=4),
+                                           ])
+
+        bayes_search = BayesSearchCV(
+                estimator=search_space.pipeline(),  # noqa
+                search_spaces=search_space.search_spaces(),  # noqa
+                cv=RepeatedKFold(n_splits=3, n_repeats=1, random_state=42),  # 3 fold 1 repeat CV
+                scoring='roc_auc',
+                refit=False,  # required if passing in multiple scorers
+                return_train_score=False,
+                n_jobs=-1,
+                verbose=0,
+                random_state=42,
+            )
+        _ = bayes_search.fit(self.X_train, self.y_train)
+
         results = MLExperimentResults.from_sklearn_search_cv(
-            searcher=self.bayes_search,
+            searcher=bayes_search,
             higher_score_is_better=True,
             description='BayesSearchCV using ClassifierSearchSpace',
-            parameter_name_mappings=self.search_space_used.param_name_mappings()
+            parameter_name_mappings=search_space.param_name_mappings()
         )
 
         results.to_yaml_file(get_test_path() + '/test_files/sklearn_search/multi-model-search.yaml')
@@ -274,7 +335,9 @@ class TestSklearnSearch(unittest.TestCase):
         # pd.set_option('display.width', 10000)
 
         def label_column_formatter(label_column):
-            return [str(value).replace('<br>', '; ').replace('; model', '\nmodel').replace('; ', '\n       ') for value in label_column]
+            return [str(value).replace('<br>', '; ').
+                        replace('; model', '\nmodel').
+                        replace('; ', '\n       ') for value in label_column]  # noqa
 
         labeled_df = results.to_labeled_dataframe()
         with redirect_stdout_to_file(get_test_path() + '/test_files/sklearn_search/multi-model-search-labeled_dataframe.txt'):
@@ -314,24 +377,14 @@ class TestSklearnSearch(unittest.TestCase):
             file.write(to_string(labels))
         del labels
 
-    def test_MLExperimentResults_multi_model2(self):
-        # test grid search object that has one score (classification)
-        # not passing in parameter mappings
-        bayes_search = self.bayes_search
-        results = MLExperimentResults.from_sklearn_search_cv(
-            searcher=self.bayes_search,
-            higher_score_is_better=True,
-            description='BayesSearchCV using ClassifierSearchSpace',
-            parameter_name_mappings=self.search_space_used.param_name_mappings()
-        )
         self.assertEqual(results.higher_score_is_better, True)
         self.assertEqual(results.cross_validation_type, "<class 'skopt.searchcv.BayesSearchCV'>")
         self.assertEqual(results.number_of_splits,
                          bayes_search.cv.n_repeats * bayes_search.n_splits_)
         self.assertEqual(results.score_names, ['roc_auc'])
         self.assertEqual(results.parameter_names_original,
-                         list(self.search_space_used.param_name_mappings().keys()))
-        self.assertEqual(results.parameter_names, list(self.search_space_used.param_name_mappings().values()))
+                         list(search_space.param_name_mappings().keys()))
+        self.assertEqual(results.parameter_names, list(search_space.param_name_mappings().values()))
         self.assertIsNotNone(results.parameter_names_mapping)
         self.assertTrue(isinstance(results.test_score_rankings, dict))
         self.assertEqual(list(results.test_score_rankings.keys()), results.score_names)
@@ -368,9 +421,15 @@ class TestSklearnSearch(unittest.TestCase):
                                                            labeled_dataframe.drop(columns=['Trial Index',
                                                                                            'label'])])
 
+        def clean_param_name(name):
+            return str(name).\
+                replace("OneHotEncoder(handle_unknown='ignore')",
+                        "OneHotEncoder()").\
+                replace("PCA(n_components='mle')",
+                        "PCA('mle')")
+
         def remove_parentheses(obj):
-            obj = str(obj)
-            obj = obj.replace("OneHotEncoder(handle_unknown='ignore')", "OneHotEncoder()")
+            obj = clean_param_name(obj)
             return re.sub(r'\(.*', '', obj.replace('\n', ''))
 
         self.assertEqual([remove_parentheses(x) for x in bayes_search.cv_results_['param_model'].data],
@@ -378,7 +437,7 @@ class TestSklearnSearch(unittest.TestCase):
 
         # check that all of the hyper-param values match in the dataframe vs bayes_search.cv_results_
         hyper_param_df = cv_dataframe.iloc[:, 4:]
-        for key, value in self.search_space_used.param_name_mappings().items():
+        for key, value in search_space.param_name_mappings().items():
             if key != 'model':
                 mask = bayes_search.cv_results_['param_' + key].mask
                 cv_data = list(bayes_search.cv_results_['param_' + key].data)
@@ -388,9 +447,7 @@ class TestSklearnSearch(unittest.TestCase):
                     assert_np_arrays_are_close(np.array(cv_data),
                                                np.array(hyper_param_df.loc[:, value].tolist()))
                 if key.startswith('prep__'):
-                    self.assertEqual([str(x).replace("OneHotEncoder(handle_unknown='ignore')",
-                                                     "OneHotEncoder()")
-                                      for x in cv_data],
+                    self.assertEqual([clean_param_name(x) for x in cv_data],
                                      hyper_param_df.loc[:, value].tolist())
 
         self.assertTrue(isinstance(results.test_score_averages, dict))
@@ -448,13 +505,13 @@ class TestSklearnSearch(unittest.TestCase):
                                                bayes_search.best_params_[original_name]))
                 else:
                     self.assertEqual(results.best_params[new_name],
-                                     str(bayes_search.best_params_[original_name]).replace("OneHotEncoder(handle_unknown='ignore')",
-                                                                                           "OneHotEncoder()"))
+                                     clean_param_name(bayes_search.best_params_[original_name]))
 
     def test_MLExperimentResults_all_models(self):
-        search_space = ClassifierSearchSpace(
+        search_space = BayesianSearchSpace(
             data=self.X_train,
-            iterations=[1] * len(ClassifierSearchSpaceModels.list())
+            iterations=1,
+            include_default_model=False
         )
         bayes_search = BayesSearchCV(
             estimator=search_space.pipeline(),  # noqa
